diff --git a/sites/all/modules/ucount/modules/ucount_barcode/js/ucount_barcode.js b/sites/all/modules/ucount/modules/ucount_barcode/js/ucount_barcode.js
index 74293f5..c887bbd 100644
--- a/sites/all/modules/ucount/modules/ucount_barcode/js/ucount_barcode.js
+++ b/sites/all/modules/ucount/modules/ucount_barcode/js/ucount_barcode.js
@@ -1,4 +1,4 @@
-// $Id: ucount_barcode.js,v 1.2 2009/08/29 04:55:08 posco Exp $
+// $Id: ucount_barcode.js,v 1.3 2009/10/05 01:24:07 posco Exp $
 
 /**
  * @file
@@ -14,6 +14,7 @@ var ucountBarcode = ucountBarcode || { 'driver': {}, 'submitReady': false };
  */
 ucountBarcode.autoFocus = function() {
   $('.ucount-barcode:first').focus();
+  $('.ucount-barcode:first').val('');
 };
 
 /**
@@ -83,7 +84,7 @@ ucountBarcode.checkStatus = function(activityField) {
 };
 
 /**
  * Keypress event handler for textfield input forms on the iCount
  * Barcode form.
  *
  * @return
@@ -144,4 +145,4 @@ Drupal.behaviors.ucountBarcode = function() {
  */
 $(document).ready(function() {
   ucountBarcode.autoFocus();
-});
\ No newline at end of file
+});
@@ -83,7 +84,7 @@ ucountBarcode.checkStatus = function(activityField) {
 
 /**
- * Keypress event handler for textfield input forms on the iCount
+ * Keypress event handler for textfield input forms on the uCount
  * Barcode form.
  *
